@@ -3,7 +3,7 @@ from py_book_util.image_recognizer import ImageRecognizer
 import os
 import json
 from myst_nb import glue
-
+from PIL import Image
 
 class PageRecognizer(object):
     def __init__(
@@ -17,6 +17,10 @@ class PageRecognizer(object):
         dst_img_dir = self.dst_img_dir()
         if os.path.isdir(dst_img_dir) == False:
             os.mkdir(dst_img_dir)
+        if os.path.exists(self.cur_img_file()):
+            img = Image.open(self.cur_img_file())
+            self.page_width = img.width
+            self.page_height = img.height
 
     def cur_img_file(self):
         return "%s/%s.png" % (self.pages_dir, self.page_idx)
@@ -24,7 +28,54 @@ class PageRecognizer(object):
     def dst_img_dir(self):
         return "%s/%s" % (self.pages_dir, self.page_idx)
 
+    def recognize_rect_w_h(
+        self,
+        cur_key_word,
+        crop_img_left,
+        crop_img_top,
+        crop_img_width,
+        crop_img_height,
+        post_replace={},
+        flag_force=False,
+        ratio=2,
+        flag_autocrop=True,
+        app_name="img2txt",
+    ):
+        crop_img_bottom = self.page_height - crop_img_top - crop_img_height;
+        crop_img_right = self.page_width - crop_img_left - crop_img_width;
+        return self.recognize_rect_impl(cur_key_word, crop_img_top, crop_img_bottom, crop_img_left, crop_img_right, post_replace, flag_force, ratio, flag_autocrop, app_name)
+
     def recognize_rect(
+        self,
+        cur_key_word,
+        crop_img_top,
+        crop_img_bottom,
+        crop_img_left,
+        crop_img_right,
+        post_replace={},
+        flag_force=False,
+        ratio=2,
+        flag_autocrop=True,
+        app_name="img2txt",
+    ):
+        crop_img_width = self.page_width - crop_img_left - crop_img_right
+        crop_img_height = self.page_height - crop_img_top - crop_img_bottom
+        if (app_name == "img2txt"):
+            if flag_autocrop:
+                if ratio == 2:
+                    if flag_force == False:
+                        print("Deprecidated please use recognize_rect_w_h(cur_key_word, %d, %d, %d, %d, %s)" %(crop_img_left, crop_img_top, crop_img_width , crop_img_height, post_replace));
+                    else:
+                        print("Deprecidated please use recognize_rect_w_h(cur_key_word, %d, %d, %d, %d, %s, %s)" %(crop_img_left, crop_img_top, crop_img_width , crop_img_height, post_replace, flag_force));
+                else:
+                    print("Deprecidated please use recognize_rect_w_h(cur_key_word, %d, %d, %d, %d, %s, %s, %d)" %(crop_img_left, crop_img_top, crop_img_width , crop_img_height, post_replace, flag_force, ratio));
+            else:
+                print("Deprecidated please use recognize_rect_w_h(cur_key_word, %d, %d, %d, %d, %s, %s, %d, %s)" %(crop_img_left, crop_img_top, crop_img_width , crop_img_height, post_replace, flag_force, ratio, flag_autocrop));
+        else:
+            print("Deprecidated please use recognize_rect_w_h(cur_key_word, %d, %d, %d, %d, %s, %s, %d, %s, '%s')" %(crop_img_left, crop_img_top, crop_img_width, crop_img_height, post_replace, flag_force, ratio, flag_autocrop, app_name));
+        return self.recognize_rect_impl(cur_key_word, crop_img_top, crop_img_bottom, crop_img_left, crop_img_right, post_replace, flag_force, ratio, flag_autocrop, app_name)
+
+    def recognize_rect_impl(
         self,
         cur_key_word,
         crop_img_top,
